@@ -27,7 +27,7 @@ def main(argv=None):
     opts = ''
 
     try:
-        opts, args = getopt.getopt(argv, "hf:o:n:g:c:", ["help", "file=", "name=", "git-repository-ssh=",
+        opts, args = getopt.getopt(argv, "hV:f:o:n:g:c", ["help", "version", "file=", "name=", "git-repository-ssh=",
                                                        "out-folder=", "customer="])
     except getopt.GetoptError:
         usage()
@@ -36,6 +36,9 @@ def main(argv=None):
         if opt in ("-h", "--help"):
             usage()
             exit()
+        elif opt in ("-V", "--version"):
+            show_version()
+            exit()
         elif opt in ("-f", "--file"):
             inputfile = arg
         elif opt in ("-c", "--customer-id"):
@@ -60,6 +63,18 @@ def main(argv=None):
 
     parse_xml(inputfile, name, customer, outfolder, git_repo)
 
+def show_version():
+    import re
+    VERSIONFILE="src/__version__.py"
+    verstrline = open(VERSIONFILE, "rt").read()
+    VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
+    mo = re.search(VSRE, verstrline, re.M)
+    if mo:
+        verstr = mo.group(1)
+    else:
+        raise RuntimeError("Unable to find version string in %s." % (VERSIONFILE,))
+    print("version {}".format(verstr))
+
 
 def usage():
     print("usage :")
@@ -104,6 +119,7 @@ def parse_xml(xml, app_name, customer, outfolder, git_repo):
     description = ""
     dependents = ""
     batchs = ""
+    methods = ""
 
     if hasattr(app_tree.Application, "Props"):
         props = app_tree.Application.Props
@@ -140,6 +156,10 @@ def parse_xml(xml, app_name, customer, outfolder, git_repo):
         if hasattr(app_tree.Application.BatchJobs, "Event"):
             batchs = app_tree.Application.BatchJobs.Event
 
+    if hasattr(app_tree.Application, "CustomMethods"):
+        if hasattr(app_tree.Application.CustomMethods, "CustomMethod"):
+            methods = app_tree.Application.CustomMethods.CustomMethod
+
     my_app = App(
         app_name,
         app_tree.Application["id"],
@@ -148,7 +168,7 @@ def parse_xml(xml, app_name, customer, outfolder, git_repo):
         app_tree.Application.DisplayName.cdata,
         description,
         props, objects, hosted, menus, webpages, portals, seeds, dependents, batchs,
-        outfolder, git_repo, date_creation_fichier
+        outfolder, git_repo, date_creation_fichier, methods
     )
     if git_repo:
         my_app.check_git_exists()
