@@ -29,8 +29,8 @@ class Menu(object):
 
     def to_file(self):
         # fichier de propriétés
-        if not os.path.exists(self.menu_dir):
-            os.makedirs(self.menu_dir)
+        if not os.path.exists(self.menu_dir.encode('utf-8')):
+            os.makedirs(self.menu_dir.encode('utf-8'))
         file = open("{}/PROPERTIES.md".format(self.menu_dir), 'w+', encoding='utf-8')
         with file:
             # nom de l'objet
