@@ -27,8 +27,8 @@ class SeedRecord(object):
 
         self.seed_dir = self.portal_dir = "{}/seeds".format(app_dir)
 
-        if not os.path.exists(self.portal_dir):
-            os.makedirs(self.portal_dir)
+        if not os.path.exists(self.portal_dir.encode('utf-8')):
+            os.makedirs(self.portal_dir.encode('utf-8'))
 
     def to_file(self):
         if self.obj_name:
