@@ -16,8 +16,14 @@ class Portal(object):
         self.is_main = portal["isMain"]
         self.name = portal.SiteName.cdata
         self.stylesheet = portal.Stylesheet.cdata
-        self.header = base64.b64decode(portal.Header.cdata)
-        self.footer = base64.b64decode(portal.Footer.cdata)
+        if hasattr(portal.WebPageDefs, "Header"):
+            self.header = base64.b64decode(portal.Header.cdata)
+        else:
+            self.header = ""
+        if hasattr(portal.WebPageDefs, "Footer"):
+            self.footer = base64.b64decode(portal.Footer.cdata)
+        else:
+            self.footer = ""
         if hasattr(portal.WebPageDefs, "WebPageDef"):
             self.webpages = portal.WebPageDefs.WebPageDef
         else:
@@ -47,11 +53,11 @@ class Portal(object):
 
         header = open("{}/header.html".format(self.portal_dir), 'w+', encoding='utf-8')
         with header:
-            header.write(self.header.decode("utf-8"))
+            header.write(self.header)
 
         footer = open("{}/footer.html".format(self.portal_dir), 'w+', encoding='utf-8')
         with footer:
-            footer.write(self.footer.decode("utf-8"))
+            footer.write(self.footer)
 
         if self.webpages:
             self.create_web_pages()
